'=========================================================================================
'    Script Name         : DeviceCheck.vbs
'    Functional overview : 
'    This file is used to check target device which specified in xml Configuration file.
'    Date                : 2018-12-20
'    Author              : P.Y.
'    Version             : Rev00
'=========================================================================================
'The format of Configuration in XML file
'<configuration>
'    <config001 DeviceClass = "Win32_PointingDevice" DeviceId="HID\TOSB1003" />
'    <config002 DeviceClass = "Win32_PointingDevice" DeviceId="HID\TOSB1004" />
'</configuration>

'=========================================================================================
'    Function Name       : LoadConfig
'    Functional overview : Load configuration file.
'    Param:
'         strConfigFilePath: [in]The path of the xml Configuration file             
'         theConfigsData : [out]The container which is used to revive the data in Microsoft.XMLDOM.documentElement
'    Return              : 0 Successful, <0 Failed
'    Author              : P.Y.
'    Date                : 2018-12-20
'=========================================================================================
function LoadConfig(strConfigFilePath, theConfigsData)
'     On Error Resume Next
     DIM nConfigNum
     DIM objXMLDom, ConfigsData
     LoadConfig = 0

     set objXMLDom = Createobject("Microsoft.XMLDOM")
     if IsEmpty(objXMLDom) Then
          LoadConfig = -1
          exit function
     end if

     objXMLDom.async = False
     objXMLDom.Load(strConfigFilePath)
     If objXMLDom.parseError.errorCode <> 0 then
          msgbox "Reason: " + objXMLDom.parseError.reason,17, "Configuration file (XML) Load error"
          LoadConfig = -2
          exit function
     end if

     set ConfigsData = objXMLDom.documentElement
     nConfigNum = ConfigsData.childNodes.length
     if nConfigNum < 1 Then
          LoadConfig = -3
          exit function
     end if
     set theConfigsData = ConfigsData
     set ConfigsData = nothing
     set objXMLDom = nothing
end function

'=========================================================================================
'    Function Name       : CheckDevice
'    Functional overview : Check if the specified device is existed or not.
'    Param:
'         deviceclass:   : [in] The string which specifies the device class.
'         deviceid       : [in] The string which specifies the device id.
'    Return              : 0 Successful, < 0 Failed
'    Author              : P.Y.
'    Date                : 2018-12-20
'=========================================================================================
function CheckDevice(deviceclass, deviceid)
     On Error Resume Next
     Dim objWMIService, colItems,objItem
     Dim strQuery, strComputer
     CheckDevice = -1    
     strComputer = "."
     'Get Object via WMI
     strQuery = "SELECT * FROM " + deviceclass
     Set objWMIService = GetObject("winmgmts:\\" & strComputer & "\root\CIMV2") 
     Set colItems = objWMIService.ExecQuery(strQuery,,48)
     
     for each objItem in colItems
          if instr(objItem.DeviceID , deviceid)>0 then
               CheckDevice = 0
               exit for
          end if
     next

     set objWMIService = nothing
     set colItems = nothing
end function

'=========================================================================================
'    Function Name       : CheckDevices
'    Functional overview : Check if the specified devices is existed or not.
'    Param:
'         strConfigFilePath: [in]The path of the xml Configuration file   
'         IsCheckSingle  : [in] A Boolean type value which indicates checking all devices or not.
'                          True: At least one device is existed.
'                          False: Need Check all devices.
'    Return              : 0 Successful, < 0 Failed
'    Author              : P.Y.
'    Date                : 2018-12-20
'=========================================================================================
function CheckDevices(strConfigFilePath, IsCheckSingle)
     DIM ConfigsData, childNode
     DIM nRet
     DIM strConfig, strDeviceClass, strDeviceId
     CheckDevices = -1

     nRet = LoadConfig(strConfigFilePath, ConfigsData)

     if nRet < 0 Then
          CheckDevices = nRet
          exit function
     end if

     for each childNode in ConfigsData.childNodes
          'Get the Device Class and Device Id from the configuration
          strDeviceClass = childNode.GetAttributeNode("deviceclass").Nodevalue
          strDeviceId = childNode.GetAttributeNode("deviceid").Nodevalue
          nRet = CheckDevice(strDeviceClass,strDeviceId)
          if (nRet = 0) Then
               if IsCheckSingle Then
                    CheckDevices = 0
                    exit for     
               else
                    CheckDevices = 0
               end if
          elseif Not IsCheckSingle Then
               CheckDevices = -1
               exit for
          end if
     next

     set ConfigsData = nothing    
end function
